@@ -9,14 +9,11 @@ from kivy.uix.screenmanager import ScreenManager, Screen
 from kivy.uix.scrollview import ScrollView
 from kivy import utils
 from producetracker.utilities import SwipeListener, Produce, valid_string
+# from producetracker.installer import installer
 from producetracker.database import *
+import os
 import os.path
 import sys
-# basepath = os.path.dirname(os.path.abspath(__file__))
-# sys.path.insert(0, basepath)
-
-print("Path is ***************************")
-print(os.path.join(os.path.dirname(__file__), 'resources'))
 
 import kivy.resources
 kivy.resources.resource_add_path(os.path.join(os.path.dirname(__file__), 'resources'))
@@ -198,12 +195,14 @@ class ScrollMenu(ScrollView):
 
 class BadApplesApp(App):
     def build(self):
-        print("FILE IS " + str(__file__))
-        print(os.path.join(os.path.dirname(__file__), 'style.kv'))
         root = Builder.load_file(os.path.join(os.path.dirname(__file__), 'style.kv'))
         return root
 
 def main():
+    os.system("sudo apt-get install xclip xsel")
+    os.system("sudo apt install tesseract-ocr")
+    # os.system("sudo apt-get remove gstreamer1.0-alsa gstreamer1.0-libav gstreamer1.0-plugins-bad gstreamer1.0-plugins-base gstreamer1.0-plugins-good gstreamer1.0-plugins-ugly gstreamer1.0-pulseaudio libgstreamer-plugins-bad1.0-0 libgstreamer-plugins-base1.0-0 libgstreamer-plugins-good1.0-0 libgstreamer1.0-0")
+
     BadApplesApp().run()
 
 if __name__ == "__main__":
